(function() {
  var HelloWorld;

  HelloWorld = (function() {
    class HelloWorld {};

    HelloWorld.test = 'test';

    return HelloWorld;

  }).call(this);

  console.log('hi');

}).call(this);
